Geometry
========

Classes
-------

.. currentmodule:: ansys.edb.core.geometry

.. autosummary::
   :toctree: _autosummary

   arc_data.ArcData
   r_tree.RTree
   r_tree.RTreeObj
   polygon_data.PolygonData
   point_data.PointData
   point3d_data.Point3DData
   triangle3d_data.Triangle3DData

Enums
-----

.. autosummary::
   :toctree: _autosummary

   arc_data.RotationDirection
   polygon_data.ExtentType
   polygon_data.PolygonSenseType
   polygon_data.IntersectionType
